
# Installation

## with pip <small>recommended</small>

EasyLLM is published as a [Python package] and can be installed with
`pip` from pypi or from the Github repository, Open up a terminal and install.
=== "Latest"

    ``` sh
    pip install easyllm
    ```
=== "Github"

    ``` sh
    pip install git+https://github.com/philschmid/easyllm
    ```